@@ -32,9 +32,8 @@
 #include "maindlg.h"
 
 // KDE includes
-#include <kglobal.h>
 #include <kinputdialog.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kmessagebox.h>
 
 #include <QList>
